@@ -23,7 +23,7 @@
 class PlotStyleDialogWidget : public QWidget, public Ui::PlotStyleWidget
 {
 public:
-    PlotStyleDialogWidget(QWidget *parent = 0)
+    PlotStyleDialogWidget(QWidget *parent = nullptr)
         : QWidget(parent)
     {
         setupUi(this);
@@ -117,3 +117,5 @@ void PlotStyleWidget::advancedOptions()
     m_dialog->show();
 }
 // END class PlotStyleWidget
+
+#include "moc_plotstylewidget.cpp"
